@@ -24,7 +24,7 @@ class ConfigDebug(Config):
     """
     Parameters for debug
     """
-    verbose = ParamCreator.create_bool(
+    debug_verbose = ParamCreator.create_bool(
         help_string="be verbose?",
         default=False,
     )
@@ -32,10 +32,6 @@ class ConfigDebug(Config):
         help_string="add --verbose when running git?",
         default=False,
     )
-    quiet = ParamCreator.create_bool(
-        help_string="be quiet?",
-        default=False,
-    )
     git_quiet = ParamCreator.create_bool(
         help_string="add --quiet when running git?",
         default=False,
